#include "application.h"

Application::Application()
{
	_RWindow.Create(sf::VideoMode(768, 576), "Crab", sf::Style::Close);
	_RWindow.UseVerticalSync(false);
	_RWindow.GetDefaultView().SetFromRect(sf::FloatRect(0, 0, 192, 144));
	_RWindow.ShowMouseCursor(false);

	alutInit(0, 0);
	if (alutGetError() != ALUT_ERROR_NO_ERROR)
	{
		cout << "Error on ALUT Initialization !" << endl;
		_RWindow.Close();
	}

	_fullscreen = false;
	_load = false;

//	_CursorImage.Create(1, 1, sf::Color(255, 0, 0));
	_CursorImage.LoadFromFile("data/graphics/cursor.bmp");
	_CursorImage.CreateMaskFromColor(sf::Color(255, 0, 255));
	_CursorImage.SetSmooth(false);
	_CursorSprite.SetImage(_CursorImage);
	_CursorSprite.SetCenter(3, 3);
	_CursorPosition.x = 0;
	_CursorPosition.y = 0;

	_FilterImage.LoadFromFile("data/graphics/filter.png");
	_FilterImage.SetSmooth(false);
	_FilterSprite.SetImage(_FilterImage);

	_FogImage.LoadFromFile("data/graphics/fog.png");
	_FogImage.SetSmooth(false);
	_FogSprite.SetImage(_FogImage);
	_fogTimer = 0.f;
	_fogX = 0;

	_FadeImage.Create(192, 144, sf::Color(0, 0, 0, 0));
	_FadeImage.SetSmooth(false);
	_FadeSprite.SetImage(_FadeImage);
	_fadeTimer = 0.f;
	_fadeLevel = 0;
	_fade = 0;

	_DoorImage.LoadFromFile("data/graphics/dooricn.bmp");
	_DoorImage.SetSmooth(false);
	_DoorSprite.SetImage(_DoorImage);
	_DoorSprite.SetPosition(90, 132);

	_TunnelImage.LoadFromFile("data/graphics/tunnelicn.bmp");
	_TunnelImage.SetSmooth(false);
	_TunnelSprite.SetImage(_TunnelImage);
	_TunnelSprite.SetPosition(90, 132);

	_BedImage.LoadFromFile("data/graphics/bedicn.bmp");
	_BedImage.SetSmooth(false);
	_BedSprite.SetImage(_BedImage);
	_BedSprite.SetPosition(90, 132);

	_Player.SetApp(this);
	_StartPosition.x = 50;
	_StartPosition.y = 50;
	_Scene = S_INTRO;
	_NewScene = S_NONE;

	_CorruptionSound.LoadFromFile("data/sounds/corruption.wav");
	_HeartbeatSound.LoadFromFile("data/sounds/heartbeat.wav");
	_BipSound.LoadFromFile("data/sounds/bip.wav");
	_LightSound.LoadFromFile("data/sounds/light_hum.wav");

	_TunnelMusic.LoadFromFile("data/sounds/tunnel.wav");
	_CavernMusic.LoadFromFile("data/sounds/cavern.wav");
	_CellMusic.LoadFromFile("data/sounds/cell.wav");

	_foreground = false;
	_interact = false;

	_h3corrupted = false;
	_h4corrupted = false;
}


int Application::Exec()
{
	Draw();
	return EXIT_SUCCESS;
}


void Application::Draw()
{
	while (_RWindow.IsOpened())
	{
		_interact = false;
		HandleEvent();

		if (_Scene == S_H1 || _Scene == S_H1_I || _Scene == S_H2 || _Scene == S_TUNNEL) _CavernMusic.Play();
		else _CavernMusic.Stop();

		if (_Scene == S_H4_1 || _Scene == S_H4_2) _TunnelMusic.Play();
		else _TunnelMusic.Stop();

		if (_Scene == S_H2 || _Scene == S_H2_I || _Scene == S_H3) _CellMusic.Play();
		else _CellMusic.Stop();

		if (_Scene == S_CHURCH) _HeartbeatSound.Play();
		else if (_Scene != S_CHURCH_I) _HeartbeatSound.Stop();

		if (_Scene == S_HOSPITAL) _BipSound.PlayOnce();
		else _BipSound.Stop();

		_RWindow.Clear(sf::Color(0, 0, 0));
		_RWindow.Draw(_BGSprite);
		Script();
		if (_Scene != S_HOSPITAL && _Scene != S_INTRO && _Scene != S_TITLE) _Player.Display();
		if (_Scene == S_H1 || _Scene == S_H2 || _Scene == S_H3 || _Scene == S_CHURCH)
		{
			_fogTimer += _RWindow.GetFrameTime();
			if (_fogTimer >= 0.2f)
			{
				_fogX += 1;
				if (_fogX == 576) _fogX = 0;
				_fogTimer = 0.f;
			}
			_FogSprite.SetSubRect(sf::Rect<int>(_fogX, 0, _fogX + 192, 144));
			_RWindow.Draw(_FogSprite);
		}
		if (_foreground) _RWindow.Draw(_FGSprite);
		if (_Scene != S_HOSPITAL && _Scene != S_INTRO && _Scene != S_TITLE) _RWindow.Draw(_CursorSprite);
		_RWindow.Draw(_FilterSprite);

		if (_NewScene != S_NONE)
		{
			if (_fade == 1)
			{
				_fadeTimer += _RWindow.GetFrameTime();
				if (_fadeTimer > 0.4f)
				{
					_fadeTimer = 0.8f;
					_Scene = _NewScene;
					_load = false;
					_fade = 2;
				}
			}
			else if (_fade == 2)
			{
				_fadeTimer -= _RWindow.GetFrameTime();
				if (_fadeTimer <= 0.f)
				{
					_fadeTimer = 0.f;
					_NewScene = S_NONE;
					_fade = 0;
				}
			}
			else
			{
				_Scene = _NewScene;
				_NewScene = S_NONE;
				_load = false;
			}
		}

		if (_fadeTimer)
		{
			if (_fadeTimer >= 0.4f) _fadeLevel = 255;
			else if (_fadeTimer >= 0.3f) _fadeLevel = 192;
			else if (_fadeTimer >= 0.2f) _fadeLevel = 128;
			else if (_fadeTimer >= 0.1f) _fadeLevel = 64;
			else _fadeLevel = 0;

			_FadeImage.Create(192, 144, sf::Color(0, 0, 0, _fadeLevel));
			_FadeSprite.SetImage(_FadeImage);
			_RWindow.Draw(_FadeSprite);
		}

		_RWindow.Display();
	}
}


void Application::Script()
{
	if (!_load)
	{
		_Player.GetSprite()->SetPosition(_StartPosition);

		if (_Scene == S_INTRO)
		{
			_BGImage.LoadFromFile("data/graphics/intro.png");
			_foreground = false;
		}
		else if (_Scene == S_TITLE)
		{
			_BGImage.LoadFromFile("data/graphics/title.png");
			_foreground = false;
		}
		else if (_Scene == S_H1)
		{
			_BGImage.LoadFromFile("data/graphics/h1.png");
			_FGImage.LoadFromFile("data/graphics/h1_fg.png");
			_foreground = true;
			_CavernMusic.SetVolume(0.8f);
		}
		else if (_Scene == S_H1_I)
		{
			_BGImage.LoadFromFile("data/graphics/h1_i.png");
			_FGImage.LoadFromFile("data/graphics/h1_i_fg.png");
			_foreground = true;
			_CavernMusic.SetVolume(1.f);
		}
		else if (_Scene == S_H2)
		{
			_BGImage.LoadFromFile("data/graphics/h2.png");
			_FGImage.LoadFromFile("data/graphics/h2_fg.png");
			_foreground = true;
		}
		else if (_Scene == S_H2_I)
		{
			_BGImage.LoadFromFile("data/graphics/h2_i.png");
			_foreground = false;
			_DImage.Create(1, 1, sf::Color(8, 8, 8));
			_DImage.SetSmooth(false);
			_DSprite.SetImage(_DImage);
			_timer0 = 0.f;
			_timer1 = 0.f;
		}
		else if (_Scene == S_H3)
		{
			if (_h3corrupted)
				_BGImage.LoadFromFile("data/graphics/h3_c.png");
			else
				_BGImage.LoadFromFile("data/graphics/h3.png");
			_CellMusic.SetVolume(1.f);
			_FGImage.LoadFromFile("data/graphics/h3_fg.png");
			_foreground = true;
		}
		else if (_Scene == S_H3_I)
		{
			if (_h3corrupted)
			{
				_BGImage.LoadFromFile("data/graphics/h3_i_c.png");
				_FGImage.LoadFromFile("data/graphics/h3_i_fg_c.png");
			}
			else
			{
				_BGImage.LoadFromFile("data/graphics/h3_i.png");
				_FGImage.LoadFromFile("data/graphics/h3_i_fg.png");
			}
			_foreground = true;
		}
		else if (_Scene == S_TUNNEL)
		{
			if (_h4corrupted)
				_BGImage.LoadFromFile("data/graphics/tunnel_c.png");
			else
				_BGImage.LoadFromFile("data/graphics/tunnel.png");
			_FGImage.LoadFromFile("data/graphics/tunnel_fg0.png");
			_foreground = true;
			_timer0 = 0.f;
		}
		else if (_Scene == S_H4_1)
		{
			if (_h4corrupted)
				_BGImage.LoadFromFile("data/graphics/h4_1_c.png");
			else
				_BGImage.LoadFromFile("data/graphics/h4_1.png");
			_foreground = false;
			_timer0 = 0.f;
		}
		else if (_Scene == S_H4_2)
		{
			if (_h4corrupted)
				_BGImage.LoadFromFile("data/graphics/h4_2_c.png");
			else
				_BGImage.LoadFromFile("data/graphics/h4_2.png");
			_foreground = false;
			_timer0 = 0.f;
		}
		else if (_Scene == S_CHURCH)
		{
			_BGImage.LoadFromFile("data/graphics/church.png");
			_FGImage.LoadFromFile("data/graphics/church_fg.png");
			_foreground = true;
			_HeartbeatSound.SetVolume(0.5f);

			_DImage.LoadFromFile("data/graphics/proliferation.png");
			_DImage.SetSmooth(false);
			_DSprite.SetImage(_DImage);
			_DSprite.SetPosition(84, 73);
		}
		else if (_Scene == S_CHURCH_I)
		{
			_BGImage.LoadFromFile("data/graphics/church_i.png");
			_FGImage.LoadFromFile("data/graphics/church_i_fg.png");
			_foreground = true;
			_HeartbeatSound.Stop();
			_HeartbeatSound.SetVolume(1.f);

			_DImage.LoadFromFile("data/graphics/heart.png");
			_DImage.SetSmooth(false);
			_DSprite.SetImage(_DImage);
			_DSprite.SetPosition(92, 64);
		}
		else if (_Scene == S_HOSPITAL)
		{
			_BGImage.LoadFromFile("data/graphics/hospital.png");
			_foreground = false;

			_timer0 = 0.f;
		}


		_BGImage.SetSmooth(false);
		_BGSprite.SetImage(_BGImage);

		if (_foreground)
		{
			_FGImage.SetSmooth(false);
			_FGSprite.SetImage(_FGImage);
		}

		_load = true;
	}

	if (_Scene == S_INTRO)
	{
		if (_interact) SetScene(S_TITLE, true);
	}
	if (_Scene == S_TITLE)
	{
		if (_interact) SetScene(S_H2_I, true);
	}
	else if (_Scene == S_H1)
	{
		if (_Player.GetSprite()->GetPosition().x > 182)
		{
				SetScene(S_H2);
				_StartPosition.x = 15;
				_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}
		if (_Player.GetInside(sf::Rect<int>(49, 80, 70, 112)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H1_I, true);
				_StartPosition.x = 36;
				_StartPosition.y = 100;
			}
		}
		if (_Player.GetInside(sf::Rect<int>(115, 41, 164, 112)))
		{
			_RWindow.Draw(_TunnelSprite);
			if (_interact)
			{
				SetScene(S_TUNNEL, true);
				_StartPosition.x = 15;
				_StartPosition.y = 100;
			}
		}
	}
	else if (_Scene == S_H1_I)
	{
		if (_Player.GetInside(sf::Rect<int>(26, 84, 47, 116)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H1, true);
				_StartPosition.x = 59;
				_StartPosition.y = 96;
			}
		}
	}
	else if (_Scene == S_H2)
	{
		int xPos = _Player.GetSprite()->GetPosition().x;
		if (xPos > 80) xPos = 80;
		float factor = (float) xPos / 80.f;
		factor *= 0.8f;
		factor = 0.8f - factor;
		_CavernMusic.SetVolume(factor);

		if (_Player.GetSprite()->GetPosition().x < 10)
		{
			SetScene(S_H1);
			_StartPosition.x = 177;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_Player.GetSprite()->GetPosition().x > 182)
		{
			SetScene(S_H3);
			_StartPosition.x = 15;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_Player.GetInside(sf::Rect<int>(153, 80, 174, 112)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H2_I, true);
				_StartPosition.x = 36;
				_StartPosition.y = 100;
			}
		}
	}
	else if (_Scene == S_H2_I)
	{
		if (_timer0 < 3.f)
		{
			_timer0 += _RWindow.GetFrameTime();
			if (_timer0 >= 3.f)
			{
				_DSprite.SetPosition(134, 88);
				_timer1 = 0.f;
			}
		}
		else
		{
			_timer1 += _RWindow.GetFrameTime();

			int off = 88 + _timer1 * 50.f;
			_DSprite.SetPosition(134, off);
			if (off >= 116)
			{
				_timer0 = 0.f;
			}
			_RWindow.Draw(_DSprite);
		}

		if (_Player.GetInside(sf::Rect<int>(26, 84, 47, 116)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H2, true);
				_StartPosition.x = 163;
				_StartPosition.y = 96;
			}
		}
	}
	else if (_Scene == S_H3)
	{
		if (_Player.GetSprite()->GetPosition().x < 10)
		{
			SetScene(S_H2);
			_StartPosition.x = 177;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_Player.GetSprite()->GetPosition().x > 182)
		{
			SetScene(S_CHURCH);
			_StartPosition.x = 15;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_Player.GetInside(sf::Rect<int>(105, 80, 126, 112)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H3_I, true);
				_StartPosition.x = 36;
				_StartPosition.y = 100;
			}
		}
	}
	else if (_Scene == S_H3_I)
	{
		if (_Player.GetInside(sf::Rect<int>(26, 84, 47, 116)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H3, true);
				_StartPosition.x = 115;
				_StartPosition.y = 96;
			}
		}

		static int h3fl = 0;
		if (!_h3corrupted && _Player.GetInside(sf::Rect<int>(137, 107, 175, 128)))
		{
			_RWindow.Draw(_BedSprite);
			if (_interact)
			{
				h3fl = 1;
			}
		}
		if (h3fl == 1)
		{
			_fadeTimer += _RWindow.GetFrameTime();

			if (_fadeTimer >= 2.f)
			{
				_CorruptionSound.Stop();
				_CorruptionSound.PlayOnce();
				_h3corrupted = true;
				SetScene(S_H3_I);
				_StartPosition.x = 157;
				_StartPosition.y = 117;
				h3fl = 2;
				_fadeTimer = 0.5f;
			}
		}
		else if (h3fl == 2)
		{
			_fadeTimer -= _RWindow.GetFrameTime() / 10.f;
			if (_fadeTimer <= 0.f)
			{
				_fadeTimer = 0.f;
				h3fl = 0;
			}
		}
	}
	else if (_Scene == S_TUNNEL)
	{
		static bool flash = false;
		static float flashSeq = 2.f;
		static float flashDuration = 0.2f;
		static int seq = 0;

		_timer0 += _RWindow.GetFrameTime();
		if (flashSeq != 0.f)
		{
			if (_timer0 > flashSeq && !flash)
			{
				_LightSound.Play();
				_FGImage.LoadFromFile("data/graphics/tunnel_fg1.png");
				_FGSprite.SetImage(_FGImage);
				flash = true;
			}
			else if (_timer0 > flashSeq + flashDuration && flash)
			{
				_LightSound.Stop();
				_FGImage.LoadFromFile("data/graphics/tunnel_fg0.png");
				_FGSprite.SetImage(_FGImage);
				flash = false;
				_timer0 = 0.f;
				seq++;
				
				if (seq == 1) {
					flashSeq = 1.f;
					flashDuration = 0.1f;
				} else if (seq == 2) {
					flashSeq = 3.f;
					flashDuration = 0.1f;
				} else if (seq == 3) {
					flashSeq = 0.5f;
					flashDuration = 0.2f;
				} else if (seq == 4) {
					flashSeq = 0.5f;
					flashDuration = 0.2f;
				} else if (seq == 5) {
					flashSeq = 0.5f;
					flashDuration = 0.2f;
				} else if (seq == 6) {
					flashSeq = 2.75f;
					flashDuration = 0.1f;
				} else if (seq == 7) {
					flashSeq = 1.f;
					flashDuration = 0.2f;
				} else if (seq == 8) {
					flashSeq = 0.8f;
					flashDuration = 0.2f;
				} else if (seq == 9) {
					flashSeq = 1.2f;
					flashDuration = 0.1f;
				} else if (seq == 10) {
					flashSeq = 3.f;
					flashDuration = 0.1f;
				} else if (seq == 11) {
					flashSeq = 1.5f;
					flashDuration = 0.2f;
				} else if (seq == 12) {
					flashSeq = 0.5f;
					flashDuration = 0.1f;
				} else if (seq == 13) {
					flashSeq = 0.75f;
					flashDuration = 0.1f;
				} else if (seq == 14) {
					flashSeq = 3.f;
					flashDuration = 0.1f;
				} else if (seq == 15) {
					flashSeq = 0.75f;
					flashDuration = 0.2f;
				} else if (seq == 16) {
					flashSeq = 3.75f;
					flashDuration = 0.1f;
				} else if (seq == 17) {
					flashSeq = 0.75f;
					flashDuration = 0.1f;
				} else if (seq == 18) {
					flashSeq = 1.f;
					flashDuration = 0.1f;
				} else if (seq == 19) {
					flashSeq = 4.f;
					flashDuration = 0.1f;
				} else if (seq == 20) {
					flashSeq = 0.5f;
					flashDuration = 0.1f;
				} else if (seq == 21) {
					flashSeq = 3.5f;
					flashDuration = 0.1f;
				} else if (seq == 22) {
					flashSeq = 0.5f;
					flashDuration = 0.2f;
				} else if (seq == 23) {
					flashSeq = 0.f;
				}
			}
		}

		int xPos = _Player.GetSprite()->GetPosition().x;
		if (xPos > 100) xPos = 100;
		float factor = (float) xPos / 100.f;
		factor *= 0.5f;
		factor = 0.8f - factor;
		_CavernMusic.SetVolume(factor);

		if (_Player.GetSprite()->GetPosition().x < 10)
		{
			SetScene(S_H1, true);
			_StartPosition.x = 140;
			_StartPosition.y = 82;
		}

		if (_Player.GetInside(sf::Rect<int>(131, 84, 152, 116)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_H4_1, true);
				_StartPosition.x = 155;
				_StartPosition.y = 100;
			}
		}
	}
	else if (_Scene == S_H4_1)
	{
		if (_Player.GetSprite()->GetPosition().x < 10)
		{
			SetScene(S_H4_2);
			_StartPosition.x = 177;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_Player.GetInside(sf::Rect<int>(144, 84, 165, 116)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_TUNNEL, true);
				_StartPosition.x = 142;
				_StartPosition.y = 100;
			}
		}
	}
	else if (_Scene == S_H4_2)
	{
		static int h4fl = 0;
		if (!_h4corrupted && _Player.GetInside(sf::Rect<int>(17, 107, 55, 128)))
		{
			_RWindow.Draw(_BedSprite);
			if (_interact)
			{
				h4fl = 1;
			}
		}
		if (_Player.GetSprite()->GetPosition().x > 182)
		{
			SetScene(S_H4_1);
			_StartPosition.x = 15;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (h4fl == 1)
		{
			_fadeTimer += _RWindow.GetFrameTime();

			if (_fadeTimer >= 2.f)
			{
				_TunnelMusic.SetVolume(0.f);
				_CorruptionSound.Stop();
				_CorruptionSound.PlayOnce();
				_h4corrupted = true;
				SetScene(S_H4_2);
				_StartPosition.x = 36;
				_StartPosition.y = 117;
				h4fl = 2;
				_fadeTimer = 0.5f;
			}
		}
		else if (h4fl == 2)
		{
			_fadeTimer -= _RWindow.GetFrameTime() / 10.f;
			if (_fadeTimer <= 0.f)
			{
				_fadeTimer = 0.f;
				h4fl = 0;
			}
		}
	}
	else if (_Scene == S_CHURCH)
	{
		static int f = 0;
		if (_Player.GetSprite()->GetPosition().x < 10)
		{
			SetScene(S_H3);
			_StartPosition.x = 177;
			_StartPosition.y = _Player.GetSprite()->GetPosition().y;
		}

		if (_h3corrupted && _h4corrupted && _Player.GetInside(sf::Rect<int>(84, 80, 108, 117)))
		{
			_RWindow.Draw(_DoorSprite);
			if (_interact)
			{
				SetScene(S_CHURCH_I, true);
				_StartPosition.x = 96;
				_StartPosition.y = 100;
			}
		}

		if (!_h3corrupted || !_h4corrupted)
		{
			_timer0 += _RWindow.GetFrameTime();
			if (_timer0 > 0.3f)
			{
				f = !f;
				_timer0 = 0.f;
			}
			_DSprite.SetSubRect(sf::Rect<int>(0 + f * 24, 0, 24 + f * 24, 40));
			_RWindow.Draw(_DSprite);
		}
	}
	else if (_Scene == S_CHURCH_I)
	{
		static int hf = 0;
		static bool finalBed = false;

		_timer0 += _RWindow.GetFrameTime();
		if (_timer0 > 0.855f)
		{
			_HeartbeatSound.Stop();
			_HeartbeatSound.PlayOnce();
			_timer0 = 0.f;
		}
		if (_timer0 > 0.f && _timer0 < 0.3f) hf = 1;
		else hf = 0;
		_DSprite.SetSubRect(sf::Rect<int>(0 + hf * 9, 0, 9 + hf * 9, 12));
		_RWindow.Draw(_DSprite);

		if (_Player.GetInside(sf::Rect<int>(137, 96, 175, 119)))
		{
			_RWindow.Draw(_BedSprite);
			if (_interact)
			{
				finalBed = true;
			}
		}

		if (finalBed)
		{
			_fadeTimer += _RWindow.GetFrameTime();

			float factor = _fadeTimer / 5.f;
			if (factor < 0.f) factor = 0.f;
			factor = 1.f - factor;
			_HeartbeatSound.SetVolume(factor);

			if (_fadeTimer >= 5.f)
			{
				SetScene(S_HOSPITAL, true);
				_fadeTimer = 0.5f;
			}
		}
	}
	else if (_Scene == S_HOSPITAL)
	{
		_fadeTimer += _RWindow.GetFrameTime() / 34.f;

		_timer0 += _RWindow.GetFrameTime();
		if (_timer0 >= 25.f) _RWindow.Close();
	}
}


void Application::HandleEvent()
{
	sf::Event Event;

	while (_RWindow.GetEvent(Event))
	{
		if (Event.Type == sf::Event::Closed)
		{
			_RWindow.Close();
		}

		if (Event.Type == sf::Event::KeyPressed && Event.Key.Code == sf::Key::Q)
			_RWindow.Close();

		if (Event.Type == sf::Event::KeyReleased && (Event.Key.Code == sf::Key::F || Event.Key.Code == sf::Key::F11))
		{
			if (_fullscreen)
			{
				_RWindow.Create(sf::VideoMode(768, 576), "Crab", sf::Style::Close);
				_RWindow.GetDefaultView().SetFromRect(sf::FloatRect(0, 0, 192, 144));
			}
			else
			{
				_RWindow.Create(sf::VideoMode::GetDesktopMode(), "Crab", sf::Style::Fullscreen);
				_RWindow.GetDefaultView().SetFromRect(sf::FloatRect(0, 0, 192, 144));
				/*
				float ratio = (float)(sf::VideoMode::GetDesktopMode().Width)/(float)(sf::VideoMode::GetDesktopMode().Height);
				float offset = ((128 * ratio) - 128) / -2;
				_RWindow.GetDefaultView().SetFromRect(sf::FloatRect(offset, 0, offset + (128 * ratio), 96));
				*/
			}

			_RWindow.ShowMouseCursor(false);
			_fullscreen = !_fullscreen;
		}

		if (Event.Type == sf::Event::MouseMoved)
		{
			_CursorPosition.x = Event.MouseMove.X * 192 / _RWindow.GetWidth();
			_CursorPosition.y = Event.MouseMove.Y * 144 / _RWindow.GetHeight();
			_CursorSprite.SetPosition(_CursorPosition);
		}

		if (Event.Type == sf::Event::MouseButtonReleased && Event.MouseButton.Button == sf::Mouse::Left) _interact = true;

	}
}


sf::Vector2<float> Application::GetCursorPosition() const
{
	return _CursorPosition;
}


sf::RenderWindow* Application::GetRenderWindow()
{
	return &_RWindow;
}


int Application::GetScene() const
{
	return _Scene;
}

void Application::SetScene(int NewScene, bool fade)
{
	_NewScene = NewScene;
	_fade = fade;
}


int Application::GetFade() const
{
	return _fade;
}


Application::~Application()
{
	_CorruptionSound.Clear();
	_HeartbeatSound.Clear();
	_BipSound.Clear();
	_LightSound.Clear();

	_CellMusic.Clear();
	_CavernMusic.Clear();
	_TunnelMusic.Clear();
	alutExit();
}
